# Plugin Catalog

Available payment gateway plugins for django-getpaid.

## PayU

- **PyPI:** [`django-getpaid-payu`](https://pypi.org/project/django-getpaid-payu/)
- **Repository:** [django-getpaid/django-getpaid-payu](https://github.com/django-getpaid/django-getpaid-payu)
- **API Docs:** [PayU Developers](https://www.payu.pl/en/developers)
- **Currencies:** BGN, CHF, CZK, DKK, EUR, GBP, HRK, HUF, NOK, PLN, RON, RUB, SEK, UAH, USD

---

If you've created a plugin, please [open a PR](https://github.com/django-getpaid/django-getpaid/pulls)
to add it to this catalog.
